;
; Definition file of libpypy3-c.dll
; Automatic generated by gendef
; written by Kai Tietz 2008
;
LIBRARY "libpypy3-c.dll"
EXPORTS
HPyInit__debug
PyPyAnySet_Check
PyPyAnySet_CheckExact
PyPyArg_Parse
PyPyArg_ParseTuple
PyPyArg_ParseTupleAndKeywords
PyPyArg_UnpackTuple
PyPyArg_VaParse
PyPyArg_VaParseTupleAndKeywords
PyPyBaseObject_Type DATA
PyPyBool_FromLong
PyPyBool_Type DATA
PyPyBuffer_FillInfo
PyPyBuffer_FromContiguous
PyPyBuffer_GetPointer
PyPyBuffer_IsContiguous
PyPyBuffer_Release
PyPyBuffer_ToContiguous
PyPyBufferable_Type DATA
PyPyByteArray_AsString
PyPyByteArray_Check
PyPyByteArray_CheckExact
PyPyByteArray_Concat
PyPyByteArray_FromObject
PyPyByteArray_FromStringAndSize
PyPyByteArray_Resize
PyPyByteArray_Size
PyPyByteArray_Type DATA
PyPyBytes_AS_STRING
PyPyBytes_AsString
PyPyBytes_AsStringAndSize
PyPyBytes_Concat
PyPyBytes_ConcatAndDel
PyPyBytes_FromFormat
PyPyBytes_FromFormatV
PyPyBytes_FromObject
PyPyBytes_FromString
PyPyBytes_FromStringAndSize
PyPyBytes_Size
PyPyBytes_Type DATA
PyPyCFunction_Call
PyPyCFunction_Check
PyPyCFunction_GetFunction
PyPyCFunction_NewEx
PyPyCFunction_Type DATA
PyPyCallIter_New
PyPyCallable_Check
PyPyCapsule_GetContext
PyPyCapsule_GetDestructor
PyPyCapsule_GetName
PyPyCapsule_GetPointer
PyPyCapsule_Import
PyPyCapsule_IsValid
PyPyCapsule_New
PyPyCapsule_SetContext
PyPyCapsule_SetDestructor
PyPyCapsule_SetName
PyPyCapsule_SetPointer
PyPyCapsule_Type DATA
PyPyCell_Type DATA
PyPyClassMethodDescr_Type DATA
PyPyClassMethod_New
PyPyCode_Addr2Line
PyPyCode_Check
PyPyCode_CheckExact
PyPyCode_GetNumFree
PyPyCode_New
PyPyCode_NewEmpty
PyPyCodec_Decode
PyPyCodec_Decoder
PyPyCodec_Encode
PyPyCodec_Encoder
PyPyCodec_IncrementalDecoder
PyPyCodec_IncrementalEncoder
PyPyComplex_AsCComplex
PyPyComplex_Check
PyPyComplex_CheckExact
PyPyComplex_FromCComplex
PyPyComplex_FromDoubles
PyPyComplex_ImagAsDouble
PyPyComplex_RealAsDouble
PyPyComplex_Type DATA
PyPyContextVar_Get
PyPyContextVar_New
PyPyContextVar_Set
PyPyCoro_Check
PyPyCoro_CheckExact
PyPyDateTimeAPI DATA
PyPyDateTime_Check
PyPyDateTime_CheckExact
PyPyDateTime_DATE_GET_HOUR
PyPyDateTime_DATE_GET_MICROSECOND
PyPyDateTime_DATE_GET_MINUTE
PyPyDateTime_DATE_GET_SECOND
PyPyDateTime_DELTA_GET_DAYS
PyPyDateTime_DELTA_GET_MICROSECONDS
PyPyDateTime_DELTA_GET_SECONDS
PyPyDateTime_FromTimestamp
PyPyDateTime_GET_DAY
PyPyDateTime_GET_FOLD
PyPyDateTime_GET_MONTH
PyPyDateTime_GET_YEAR
PyPyDateTime_TIME_GET_FOLD
PyPyDateTime_TIME_GET_HOUR
PyPyDateTime_TIME_GET_MICROSECOND
PyPyDateTime_TIME_GET_MINUTE
PyPyDateTime_TIME_GET_SECOND
PyPyDate_Check
PyPyDate_CheckExact
PyPyDate_FromTimestamp
PyPyDelta_Check
PyPyDelta_CheckExact
PyPyDescr_NewClassMethod
PyPyDescr_NewGetSet
PyPyDescr_NewMethod
PyPyDictProxy_Check
PyPyDictProxy_CheckExact
PyPyDictProxy_New
PyPyDictProxy_Type DATA
PyPyDict_Clear
PyPyDict_Contains
PyPyDict_Copy
PyPyDict_DelItem
PyPyDict_DelItemString
PyPyDict_GetItem
PyPyDict_GetItemString
PyPyDict_GetItemWithError
PyPyDict_Items
PyPyDict_Keys
PyPyDict_Merge
PyPyDict_New
PyPyDict_Next
PyPyDict_SetDefault
PyPyDict_SetItem
PyPyDict_SetItemString
PyPyDict_Size
PyPyDict_Type DATA
PyPyDict_Update
PyPyDict_Values
PyPyErr_BadArgument
PyPyErr_BadInternalCall
PyPyErr_CheckSignals
PyPyErr_Clear
PyPyErr_Display
PyPyErr_ExceptionMatches
PyPyErr_Fetch
PyPyErr_Format
PyPyErr_GetExcInfo
PyPyErr_GivenExceptionMatches
PyPyErr_NewException
PyPyErr_NewExceptionWithDoc
PyPyErr_NoMemory
PyPyErr_NormalizeException
PyPyErr_Occurred
PyPyErr_Print
PyPyErr_PrintEx
PyPyErr_Restore
PyPyErr_SetExcInfo
PyPyErr_SetFromErrno
PyPyErr_SetFromErrnoWithFilename
PyPyErr_SetFromErrnoWithFilenameObject
PyPyErr_SetFromWindowsErr
PyPyErr_SetInterrupt
PyPyErr_SetNone
PyPyErr_SetObject
PyPyErr_SetString
PyPyErr_Warn
PyPyErr_WarnEx
PyPyErr_WarnExplicit
PyPyErr_WarnFormat
PyPyErr_WriteUnraisable
PyPyEval_AcquireThread
PyPyEval_CallFunction
PyPyEval_CallMethod
PyPyEval_CallObjectWithKeywords
PyPyEval_EvalCode
PyPyEval_GetBuiltins
PyPyEval_GetFrame
PyPyEval_GetGlobals
PyPyEval_GetLocals
PyPyEval_InitThreads
PyPyEval_MergeCompilerFlags
PyPyEval_ReleaseThread
PyPyEval_RestoreThread
PyPyEval_SaveThread
PyPyEval_ThreadsInitialized
PyPyExc_ArithmeticError DATA
PyPyExc_AssertionError DATA
PyPyExc_AttributeError DATA
PyPyExc_BaseException DATA
PyPyExc_BlockingIOError DATA
PyPyExc_BrokenPipeError DATA
PyPyExc_BufferError DATA
PyPyExc_BytesWarning DATA
PyPyExc_ChildProcessError DATA
PyPyExc_ConnectionAbortedError DATA
PyPyExc_ConnectionError DATA
PyPyExc_ConnectionRefusedError DATA
PyPyExc_ConnectionResetError DATA
PyPyExc_DeprecationWarning DATA
PyPyExc_EOFError DATA
PyPyExc_Exception DATA
PyPyExc_FileExistsError DATA
PyPyExc_FileNotFoundError DATA
PyPyExc_FloatingPointError DATA
PyPyExc_FutureWarning DATA
PyPyExc_GeneratorExit DATA
PyPyExc_ImportError DATA
PyPyExc_ImportWarning DATA
PyPyExc_IndentationError DATA
PyPyExc_IndexError DATA
PyPyExc_InterruptedError DATA
PyPyExc_IsADirectoryError DATA
PyPyExc_KeyError DATA
PyPyExc_KeyboardInterrupt DATA
PyPyExc_LookupError DATA
PyPyExc_MemoryError DATA
PyPyExc_ModuleNotFoundError DATA
PyPyExc_NameError DATA
PyPyExc_NotADirectoryError DATA
PyPyExc_NotImplementedError DATA
PyPyExc_OSError DATA
PyPyExc_OverflowError DATA
PyPyExc_PendingDeprecationWarning DATA
PyPyExc_PermissionError DATA
PyPyExc_ProcessLookupError DATA
PyPyExc_RecursionError DATA
PyPyExc_ReferenceError DATA
PyPyExc_ResourceWarning DATA
PyPyExc_RuntimeError DATA
PyPyExc_RuntimeWarning DATA
PyPyExc_StopAsyncIteration DATA
PyPyExc_StopIteration DATA
PyPyExc_SyntaxError DATA
PyPyExc_SyntaxWarning DATA
PyPyExc_SystemError DATA
PyPyExc_SystemExit DATA
PyPyExc_TabError DATA
PyPyExc_TimeoutError DATA
PyPyExc_TypeError DATA
PyPyExc_UnboundLocalError DATA
PyPyExc_UnicodeDecodeError DATA
PyPyExc_UnicodeEncodeError DATA
PyPyExc_UnicodeError DATA
PyPyExc_UnicodeTranslateError DATA
PyPyExc_UnicodeWarning DATA
PyPyExc_UserWarning DATA
PyPyExc_ValueError DATA
PyPyExc_Warning DATA
PyPyExc_ZeroDivisionError DATA
PyPyExceptionInstance_Class
PyPyException_GetCause
PyPyException_GetContext
PyPyException_GetTraceback
PyPyException_SetCause
PyPyException_SetContext
PyPyException_SetTraceback
PyPyFile_FromFd
PyPyFile_FromString
PyPyFile_GetLine
PyPyFile_WriteObject
PyPyFile_WriteString
PyPyFloat_AS_DOUBLE
PyPyFloat_AsDouble
PyPyFloat_FromDouble
PyPyFloat_FromString
PyPyFloat_Type DATA
PyPyFrame_New
PyPyFrozenSet_Check
PyPyFrozenSet_CheckExact
PyPyFrozenSet_New
PyPyFrozenSet_Type DATA
PyPyFunction_Check
PyPyFunction_CheckExact
PyPyFunction_GetCode
PyPyFunction_Type DATA
PyPyGILState_Check
PyPyGILState_Ensure
PyPyGILState_Release
PyPyGen_Check
PyPyGen_CheckExact
PyPyGetSetDescr_Type DATA
PyPyImport_AddModule
PyPyImport_ExecCodeModule
PyPyImport_ExecCodeModuleEx
PyPyImport_GetModule
PyPyImport_GetModuleDict
PyPyImport_Import
PyPyImport_ImportModule
PyPyImport_ImportModuleLevelObject
PyPyImport_ImportModuleNoBlock
PyPyImport_ReloadModule
PyPyIndex_Check
PyPyInstanceMethod_Check
PyPyInstanceMethod_Function
PyPyInstanceMethod_GET_FUNCTION
PyPyInstanceMethod_New
PyPyInstanceMethod_Type DATA
PyPyInterpreterState_Head
PyPyInterpreterState_Next
PyPyIter_Check
PyPyIter_Next
PyPyList_Append
PyPyList_AsTuple
PyPyList_GET_ITEM
PyPyList_GET_SIZE
PyPyList_GetItem
PyPyList_GetSlice
PyPyList_Insert
PyPyList_New
PyPyList_Reverse
PyPyList_SET_ITEM
PyPyList_SetItem
PyPyList_SetSlice
PyPyList_Size
PyPyList_Sort
PyPyList_Type DATA
PyPyLong_AsDouble
PyPyLong_AsLong
PyPyLong_AsLongAndOverflow
PyPyLong_AsLongLong
PyPyLong_AsLongLongAndOverflow
PyPyLong_AsSize_t
PyPyLong_AsSsize_t
PyPyLong_AsUnsignedLong
PyPyLong_AsUnsignedLongLong
PyPyLong_AsUnsignedLongLongMask
PyPyLong_AsUnsignedLongMask
PyPyLong_AsVoidPtr
PyPyLong_FromDouble
PyPyLong_FromLong
PyPyLong_FromLongLong
PyPyLong_FromSize_t
PyPyLong_FromSsize_t
PyPyLong_FromString
PyPyLong_FromUnicode
PyPyLong_FromUnicodeObject
PyPyLong_FromUnsignedLong
PyPyLong_FromUnsignedLongLong
PyPyLong_FromVoidPtr
PyPyLong_Type DATA
PyPyMapping_Check
PyPyMapping_GetItemString
PyPyMapping_HasKey
PyPyMapping_HasKeyString
PyPyMapping_Items
PyPyMapping_Keys
PyPyMapping_Length
PyPyMapping_SetItemString
PyPyMapping_Size
PyPyMapping_Values
PyPyMarshal_ReadObjectFromString
PyPyMarshal_WriteObjectToString
PyPyMem_Calloc
PyPyMem_Free
PyPyMem_Malloc
PyPyMem_RawCalloc
PyPyMem_RawFree
PyPyMem_RawMalloc
PyPyMem_RawRealloc
PyPyMem_Realloc
PyPyMemberDescr_Type DATA
PyPyMember_GetOne
PyPyMember_SetOne
PyPyMemoryView_Check
PyPyMemoryView_CheckExact
PyPyMemoryView_FromBuffer
PyPyMemoryView_FromMemory
PyPyMemoryView_FromObject
PyPyMemoryView_GetContiguous
PyPyMemoryView_Type DATA
PyPyMethodDescr_Check
PyPyMethodDescr_CheckExact
PyPyMethodDescr_Type DATA
PyPyMethod_Check
PyPyMethod_CheckExact
PyPyMethod_Function
PyPyMethod_New
PyPyMethod_Self
PyPyMethod_Type DATA
PyPyModuleDef_Init
PyPyModule_AddFunctions
PyPyModule_AddIntConstant
PyPyModule_AddObject
PyPyModule_AddStringConstant
PyPyModule_Check
PyPyModule_CheckExact
PyPyModule_Create2
PyPyModule_ExecDef
PyPyModule_GetDef
PyPyModule_GetDict
PyPyModule_GetName
PyPyModule_GetState
PyPyModule_New
PyPyModule_NewObject
PyPyModule_Type DATA
PyPyNumber_Absolute
PyPyNumber_Add
PyPyNumber_And
PyPyNumber_AsSsize_t
PyPyNumber_Check
PyPyNumber_Divide
PyPyNumber_Divmod
PyPyNumber_Float
PyPyNumber_FloorDivide
PyPyNumber_InPlaceAdd
PyPyNumber_InPlaceAnd
PyPyNumber_InPlaceDivide
PyPyNumber_InPlaceFloorDivide
PyPyNumber_InPlaceLshift
PyPyNumber_InPlaceMatrixMultiply
PyPyNumber_InPlaceMultiply
PyPyNumber_InPlaceOr
PyPyNumber_InPlacePower
PyPyNumber_InPlaceRemainder
PyPyNumber_InPlaceRshift
PyPyNumber_InPlaceSubtract
PyPyNumber_InPlaceTrueDivide
PyPyNumber_InPlaceXor
PyPyNumber_Index
PyPyNumber_Invert
PyPyNumber_Long
PyPyNumber_Lshift
PyPyNumber_MatrixMultiply
PyPyNumber_Multiply
PyPyNumber_Negative
PyPyNumber_Or
PyPyNumber_Positive
PyPyNumber_Power
PyPyNumber_Remainder
PyPyNumber_Rshift
PyPyNumber_Subtract
PyPyNumber_ToBase
PyPyNumber_TrueDivide
PyPyNumber_Xor
PyPyOS_AfterFork
PyPyOS_FSPath
PyPyOS_InputHook DATA
PyPyOS_InterruptOccurred
PyPyOS_double_to_string
PyPyOS_getsig
PyPyOS_setsig
PyPyOS_snprintf
PyPyOS_string_to_double
PyPyOS_vsnprintf
PyPyObject_ASCII
PyPyObject_AsCharBuffer
PyPyObject_AsFileDescriptor
PyPyObject_AsReadBuffer
PyPyObject_AsWriteBuffer
PyPyObject_Bytes
PyPyObject_Call
PyPyObject_CallFinalizerFromDealloc
PyPyObject_CallFunction
PyPyObject_CallFunctionObjArgs
PyPyObject_CallMethod
PyPyObject_CallMethodObjArgs
PyPyObject_CallObject
PyPyObject_Calloc
PyPyObject_CheckReadBuffer
PyPyObject_ClearWeakRefs
PyPyObject_Del
PyPyObject_DelAttr
PyPyObject_DelAttrString
PyPyObject_DelItem
PyPyObject_DelItemString
PyPyObject_Dir
PyPyObject_Format
PyPyObject_Free
PyPyObject_GC_Del
PyPyObject_GenericGetAttr
PyPyObject_GenericGetDict
PyPyObject_GenericSetAttr
PyPyObject_GenericSetDict
PyPyObject_GetAttr
PyPyObject_GetAttrString
PyPyObject_GetBuffer
PyPyObject_GetItem
PyPyObject_GetIter
PyPyObject_HasAttr
PyPyObject_HasAttrString
PyPyObject_Hash
PyPyObject_HashNotImplemented
PyPyObject_Init
PyPyObject_InitVar
PyPyObject_IsInstance
PyPyObject_IsSubclass
PyPyObject_IsTrue
PyPyObject_LengthHint
PyPyObject_Malloc
PyPyObject_Not
PyPyObject_Print
PyPyObject_Realloc
PyPyObject_Repr
PyPyObject_RichCompare
PyPyObject_RichCompareBool
PyPyObject_SelfIter
PyPyObject_SetAttr
PyPyObject_SetAttrString
PyPyObject_SetItem
PyPyObject_Size
PyPyObject_Str
PyPyObject_Type
PyPyObject_Unicode
PyPyProperty_Type DATA
PyPyRange_Type DATA
PyPyRun_File
PyPyRun_SimpleString
PyPyRun_String
PyPyRun_StringFlags
PyPySeqIter_New
PyPySequence_Check
PyPySequence_Concat
PyPySequence_Contains
PyPySequence_DelItem
PyPySequence_DelSlice
PyPySequence_Fast
PyPySequence_Fast_GET_ITEM
PyPySequence_Fast_GET_SIZE
PyPySequence_Fast_ITEMS
PyPySequence_GetItem
PyPySequence_GetSlice
PyPySequence_ITEM
PyPySequence_InPlaceConcat
PyPySequence_InPlaceRepeat
PyPySequence_Index
PyPySequence_Length
PyPySequence_List
PyPySequence_Repeat
PyPySequence_SetItem
PyPySequence_SetSlice
PyPySequence_Size
PyPySequence_Tuple
PyPySet_Add
PyPySet_Check
PyPySet_CheckExact
PyPySet_Clear
PyPySet_Contains
PyPySet_Discard
PyPySet_GET_SIZE
PyPySet_New
PyPySet_Pop
PyPySet_Size
PyPySet_Type DATA
PyPySlice_GetIndices
PyPySlice_GetIndicesEx
PyPySlice_New
PyPySlice_Type DATA
PyPySlice_Unpack
PyPyStaticMethod_New
PyPyStaticMethod_Type DATA
PyPyStructSequence_InitType
PyPyStructSequence_InitType2
PyPyStructSequence_New
PyPyStructSequence_NewType
PyPyStructSequence_UnnamedField DATA
PyPySys_GetObject
PyPySys_SetObject
PyPySys_WriteStderr
PyPySys_WriteStdout
PyPyTZInfo_Check
PyPyTZInfo_CheckExact
PyPyThreadState_Clear
PyPyThreadState_Delete
PyPyThreadState_DeleteCurrent
PyPyThreadState_Get
PyPyThreadState_GetDict
PyPyThreadState_New
PyPyThreadState_Swap
PyPyThread_ReInitTLS
PyPyThread_acquire_lock
PyPyThread_allocate_lock
PyPyThread_create_key
PyPyThread_delete_key
PyPyThread_delete_key_value
PyPyThread_exit_thread
PyPyThread_free_lock
PyPyThread_get_key_value
PyPyThread_get_thread_ident
PyPyThread_init_thread
PyPyThread_release_lock
PyPyThread_set_key_value
PyPyThread_start_new_thread
PyPyTime_Check
PyPyTime_CheckExact
PyPyTraceBack_Check
PyPyTraceBack_Here
PyPyTraceBack_Print
PyPyTraceBack_Type DATA
PyPyTraceMalloc_Track
PyPyTraceMalloc_Untrack
PyPyTuple_GetItem
PyPyTuple_GetSlice
PyPyTuple_New
PyPyTuple_Pack
PyPyTuple_SetItem
PyPyTuple_Size
PyPyTuple_Type DATA
PyPyType_FromSpec
PyPyType_FromSpecWithBases
PyPyType_GenericAlloc
PyPyType_GenericNew
PyPyType_GetSlot
PyPyType_IsSubtype
PyPyType_Modified
PyPyType_Ready
PyPyType_Type DATA
PyPyUnicode_AsASCIIString
PyPyUnicode_AsEncodedObject
PyPyUnicode_AsEncodedString
PyPyUnicode_AsLatin1String
PyPyUnicode_AsMBCSString
PyPyUnicode_AsUCS4
PyPyUnicode_AsUCS4Copy
PyPyUnicode_AsUTF16String
PyPyUnicode_AsUTF32String
PyPyUnicode_AsUTF8
PyPyUnicode_AsUTF8AndSize
PyPyUnicode_AsUTF8String
PyPyUnicode_AsUnicode
PyPyUnicode_AsUnicodeAndSize
PyPyUnicode_AsUnicodeEscapeString
PyPyUnicode_AsWideChar
PyPyUnicode_AsWideCharString
PyPyUnicode_Check
PyPyUnicode_CheckExact
PyPyUnicode_Compare
PyPyUnicode_CompareWithASCIIString
PyPyUnicode_Concat
PyPyUnicode_Contains
PyPyUnicode_Count
PyPyUnicode_Decode
PyPyUnicode_DecodeASCII
PyPyUnicode_DecodeFSDefault
PyPyUnicode_DecodeFSDefaultAndSize
PyPyUnicode_DecodeLatin1
PyPyUnicode_DecodeLocale
PyPyUnicode_DecodeLocaleAndSize
PyPyUnicode_DecodeMBCS
PyPyUnicode_DecodeUTF16
PyPyUnicode_DecodeUTF32
PyPyUnicode_DecodeUTF8
PyPyUnicode_EncodeASCII
PyPyUnicode_EncodeDecimal
PyPyUnicode_EncodeFSDefault
PyPyUnicode_EncodeLatin1
PyPyUnicode_EncodeLocale
PyPyUnicode_EncodeMBCS
PyPyUnicode_EncodeUTF8
PyPyUnicode_FSConverter
PyPyUnicode_FSDecoder
PyPyUnicode_Find
PyPyUnicode_FindChar
PyPyUnicode_Format
PyPyUnicode_FromEncodedObject
PyPyUnicode_FromFormat
PyPyUnicode_FromFormatV
PyPyUnicode_FromKindAndData
PyPyUnicode_FromObject
PyPyUnicode_FromOrdinal
PyPyUnicode_FromString
PyPyUnicode_FromStringAndSize
PyPyUnicode_FromUnicode
PyPyUnicode_FromWideChar
PyPyUnicode_GetDefaultEncoding
PyPyUnicode_GetLength
PyPyUnicode_GetMax
PyPyUnicode_GetSize
PyPyUnicode_InternFromString
PyPyUnicode_InternInPlace
PyPyUnicode_Join
PyPyUnicode_New
PyPyUnicode_ReadChar
PyPyUnicode_Replace
PyPyUnicode_Resize
PyPyUnicode_Split
PyPyUnicode_Splitlines
PyPyUnicode_Substring
PyPyUnicode_Tailmatch
PyPyUnicode_TransformDecimalToASCII
PyPyUnicode_Type DATA
PyPyUnicode_WriteChar
PyPyVectorcall_Call
PyPyWeakref_Check
PyPyWeakref_CheckProxy
PyPyWeakref_CheckRef
PyPyWeakref_CheckRefExact
PyPyWeakref_GET_OBJECT
PyPyWeakref_GetObject
PyPyWeakref_LockObject
PyPyWeakref_NewProxy
PyPyWeakref_NewRef
PyPyWrapperDescr_Type DATA
PyPy_AddPendingCall
PyPy_AtExit
PyPy_BuildValue
PyPy_BytesWarningFlag DATA
PyPy_CompileStringFlags
PyPy_DebugFlag DATA
PyPy_DecRef
PyPy_DontWriteBytecodeFlag DATA
PyPy_EnterRecursiveCall
PyPy_FatalError
PyPy_FindMethod
PyPy_FrozenFlag DATA
PyPy_GetProgramName
PyPy_GetRecursionLimit
PyPy_GetVersion
PyPy_HashRandomizationFlag DATA
PyPy_IgnoreEnvironmentFlag DATA
PyPy_IncRef
PyPy_InspectFlag DATA
PyPy_InteractiveFlag DATA
PyPy_IsInitialized
PyPy_IsolatedFlag DATA
PyPy_LeaveRecursiveCall
PyPy_LegacyWindowsStdioFlag DATA
PyPy_MakePendingCalls
PyPy_NoSiteFlag DATA
PyPy_NoUserSiteDirectory DATA
PyPy_OptimizeFlag DATA
PyPy_QuietFlag DATA
PyPy_ReprEnter
PyPy_ReprLeave
PyPy_SetRecursionLimit
PyPy_UNICODE_COPY
PyPy_UNICODE_ISALNUM
PyPy_UNICODE_ISALPHA
PyPy_UNICODE_ISDECIMAL
PyPy_UNICODE_ISDIGIT
PyPy_UNICODE_ISLINEBREAK
PyPy_UNICODE_ISLOWER
PyPy_UNICODE_ISNUMERIC
PyPy_UNICODE_ISSPACE
PyPy_UNICODE_ISTITLE
PyPy_UNICODE_ISUPPER
PyPy_UNICODE_TODECIMAL
PyPy_UNICODE_TODIGIT
PyPy_UNICODE_TOLOWER
PyPy_UNICODE_TONUMERIC
PyPy_UNICODE_TOTITLE
PyPy_UNICODE_TOUPPER
PyPy_UnbufferedStdioFlag DATA
PyPy_VaBuildValue
PyPy_VerboseFlag DATA
PySlice_AdjustIndices
PyThread_tss_alloc
PyThread_tss_create
PyThread_tss_delete
PyThread_tss_free
PyThread_tss_get
PyThread_tss_is_created
PyThread_tss_set
PyType_GetFlags
Py_FileSystemDefaultEncoding DATA
_PyExc_ArithmeticError DATA
_PyExc_AssertionError DATA
_PyExc_AttributeError DATA
_PyExc_BaseException DATA
_PyExc_BlockingIOError DATA
_PyExc_BrokenPipeError DATA
_PyExc_BufferError DATA
_PyExc_BytesWarning DATA
_PyExc_ChildProcessError DATA
_PyExc_ConnectionAbortedError DATA
_PyExc_ConnectionError DATA
_PyExc_ConnectionRefusedError DATA
_PyExc_ConnectionResetError DATA
_PyExc_DeprecationWarning DATA
_PyExc_EOFError DATA
_PyExc_Exception DATA
_PyExc_FileExistsError DATA
_PyExc_FileNotFoundError DATA
_PyExc_FloatingPointError DATA
_PyExc_FutureWarning DATA
_PyExc_GeneratorExit DATA
_PyExc_ImportError DATA
_PyExc_ImportWarning DATA
_PyExc_IndentationError DATA
_PyExc_IndexError DATA
_PyExc_InterruptedError DATA
_PyExc_IsADirectoryError DATA
_PyExc_KeyError DATA
_PyExc_KeyboardInterrupt DATA
_PyExc_LookupError DATA
_PyExc_MemoryError DATA
_PyExc_ModuleNotFoundError DATA
_PyExc_NameError DATA
_PyExc_NotADirectoryError DATA
_PyExc_NotImplementedError DATA
_PyExc_OSError DATA
_PyExc_OverflowError DATA
_PyExc_PendingDeprecationWarning DATA
_PyExc_PermissionError DATA
_PyExc_ProcessLookupError DATA
_PyExc_RecursionError DATA
_PyExc_ReferenceError DATA
_PyExc_ResourceWarning DATA
_PyExc_RuntimeError DATA
_PyExc_RuntimeWarning DATA
_PyExc_StopAsyncIteration DATA
_PyExc_StopIteration DATA
_PyExc_SyntaxError DATA
_PyExc_SyntaxWarning DATA
_PyExc_SystemError DATA
_PyExc_SystemExit DATA
_PyExc_TabError DATA
_PyExc_TimeoutError DATA
_PyExc_TypeError DATA
_PyExc_UnboundLocalError DATA
_PyExc_UnicodeDecodeError DATA
_PyExc_UnicodeEncodeError DATA
_PyExc_UnicodeError DATA
_PyExc_UnicodeTranslateError DATA
_PyExc_UnicodeWarning DATA
_PyExc_UserWarning DATA
_PyExc_ValueError DATA
_PyExc_Warning DATA
_PyExc_ZeroDivisionError DATA
_PyLong_AsTime_t
_PyLong_FromTime_t
_PyPyArg_NoKeywords
_PyPyArg_ParseTupleAndKeywords_SizeT
_PyPyArg_ParseTuple_SizeT
_PyPyArg_Parse_SizeT
_PyPyArg_VaParseTupleAndKeywords_SizeT
_PyPyArg_VaParse_SizeT
_PyPyBytes_Eq
_PyPyBytes_Join
_PyPyBytes_Resize
_PyPyComplex_AsCComplex
_PyPyComplex_FromCComplex
_PyPyDateTime_FromDateAndTime
_PyPyDateTime_FromDateAndTimeAndFold
_PyPyDateTime_FromTimestamp
_PyPyDateTime_Import
_PyPyDate_FromDate
_PyPyDate_FromTimestamp
_PyPyDelta_FromDelta
_PyPyDict_GetItemStringWithError
_PyPyDict_HasOnlyStringKeys
_PyPyErr_FormatFromCause
_PyPyErr_WriteUnraisableMsg
_PyPyEval_SliceIndex
_PyPyFloat_Unpack4
_PyPyFloat_Unpack8
_PyPyImport_AcquireLock
_PyPyImport_ReleaseLock
_PyPyList_Extend
_PyPyLong_AsByteArrayO
_PyPyLong_FromByteArray
_PyPyLong_NumBits
_PyPyLong_Sign
_PyPyNamespace_New
_PyPyNone_Type DATA
_PyPyNotImplemented_Type DATA
_PyPyObject_CallFunction_SizeT
_PyPyObject_CallMethod_SizeT
_PyPyObject_CallNoArg
_PyPyObject_FastCall
_PyPyObject_FastCallDict
_PyPyObject_GC_Malloc
_PyPyObject_GC_New
_PyPyObject_GC_NewVar
_PyPyObject_GetDictPtr
_PyPyObject_New
_PyPyObject_NewVar
_PyPyObject_Vectorcall
_PyPyPyGC_AddMemoryPressure
_PyPyPy_Free
_PyPyPy_Malloc
_PyPySet_Next
_PyPySet_NextEntry
_PyPyThreadState_UncheckedGet
_PyPyTimeZone_FromTimeZone
_PyPyTime_FromTime
_PyPyTime_FromTimeAndFold
_PyPyTuple_Resize
_PyPyType_Lookup
_PyPyUnicode_Ready
_PyPy_BuildValue_SizeT
_PyPy_Dealloc
_PyPy_EllipsisObject DATA
_PyPy_FalseStruct DATA
_PyPy_HashDouble
_PyPy_HashPointer
_PyPy_IsFinalizing
_PyPy_NoneStruct DATA
_PyPy_NotImplementedStruct DATA
_PyPy_PackageContext DATA
_PyPy_RestoreSignals
_PyPy_TrueStruct DATA
_PyPy_VaBuildValue_SizeT
_PyPy_get_PyOS_InputHook
_PyPy_get_capsule_type
_PyPy_object_dealloc
_PyPy_setfilesystemdefaultencoding
_PyPy_strhex
_PyPy_strhex_bytes
_PyPy_subtype_dealloc
_PyPy_tuple_dealloc
_PyPy_tuple_new
_PyTime_AsMicroseconds
_PyTime_AsMilliseconds
_PyTime_AsNanosecondsObject
_PyTime_AsSecondsDouble
_PyTime_AsTimeval
_PyTime_AsTimevalTime_t
_PyTime_AsTimeval_noraise
_PyTime_FromMillisecondsObject
_PyTime_FromNanoseconds
_PyTime_FromNanosecondsObject
_PyTime_FromSeconds
_PyTime_FromSecondsObject
_PyTime_GetMonotonicClock
_PyTime_GetMonotonicClockWithInfo
_PyTime_GetSystemClock
_PyTime_GetSystemClockWithInfo
_PyTime_Init
_PyTime_ObjectToTime_t
_PyTime_ObjectToTimespec
_PyTime_ObjectToTimeval
_PyTime_gmtime
_PyTime_localtime
_pypy_init_free
_pypy_init_home
pypy_HPyInit__debug
pypy_carefully_make_gil
pypy_debug_file DATA
pypy_execute_source
pypy_execute_source_ptr
pypy_hpy_debug_close_handle
pypy_hpy_debug_ctx_init
pypy_hpy_debug_get_ctx
pypy_hpy_debug_open_handle
pypy_hpy_debug_set_ctx
pypy_hpy_debug_unwrap_handle
pypy_init_embedded_cffi_module
pypy_init_threads
pypy_main_startup
pypy_setup_home
pypy_thread_attach
rpython_startup_code
